@@ -36,13 +36,14 @@
 #include <fcntl.h>
 #include <signal.h>
 
-#if !defined(__sun) && !defined(__NetBSD__)
-#  ifndef FREEBSD
-#    include <pty.h>
-#  else
-#    include <libutil.h>
-#  endif
+#if defined(__FreeBSD__)
+#  include <libutil.h>
+#elif defined(__OpenBSD__) || defined(__NetBSD__)
+#  include <util.h>
+#elif !defined(__sun)
+#  include <pty.h>
 #endif
+
 #include "anjuta-utils-priv.h"
 
 #include <assert.h>
@@ -53,8 +54,6 @@
 #include <glib/gi18n.h>
 #include <glib.h>
 
-#include <libgnome/gnome-macros.h>
-
 #include "anjuta-utils.h"
 #include "anjuta-marshal.h"
 #include "resources.h"
@@ -65,11 +64,15 @@
 #define FILE_BUFFER_SIZE 1024
 #define FILE_INPUT_BUFFER_SIZE		1048576
 #ifndef __MAX_BAUD
-#ifdef __CYGWIN__
-#define __MAX_BAUD B256000
-#else
-#define __MAX_BAUD B460800
-#endif
+#  if defined(B460800)
+#    define __MAX_BAUD B460800
+#  elif defined(B307200)
+#    define __MAX_BAUD B307200
+#  elif defined(B256000)
+#    define __MAX_BAUD B256000
+#  else
+#    define __MAX_BAUD B230400
+#  endif
 #endif
 
 /*
@@ -141,6 +144,9 @@ struct _AnjutaLauncherPriv
 	/* Encondig */
 	gboolean custom_encoding;
 	gchar* encoding;
+	
+	/* Env */
+	GHashTable* env;
 };
 
 enum
@@ -191,6 +197,7 @@ anjuta_launcher_initialize (AnjutaLauncher *obj)
 	obj->priv->child_pid = 0;
 	obj->priv->child_status = -1;
 	obj->priv->child_has_terminated = TRUE;
+	obj->priv->source = 0;
 	
 	/* Synchronization in progress */
 	obj->priv->in_cleanup = FALSE;
@@ -212,6 +219,10 @@ anjuta_launcher_initialize (AnjutaLauncher *obj)
 	/* Encoding */
 	obj->priv->custom_encoding = FALSE;
 	obj->priv->encoding = NULL;
+	
+	/* Env */
+	obj->priv->env = g_hash_table_new_full (g_str_hash, g_str_equal,
+											g_free, g_free);
 }
 
 GType
@@ -246,29 +257,28 @@ anjuta_launcher_dispose (GObject *obj)
 	AnjutaLauncher *launcher = ANJUTA_LAUNCHER (obj);
 	if (anjuta_launcher_is_busy (launcher))
 	{
-		pid_t child_pid_save = launcher->priv->child_pid;
-		guint child_source = launcher->priv->source;
-		g_source_remove (child_source);
+		g_source_remove (launcher->priv->source);
+		launcher->priv->source = 0;
+		
 		anjuta_launcher_execution_done_cleanup (launcher, FALSE);
 		
-		/* We can not call anjuta_launcher_reset (launcher) to kill the
-		 * running child because launcher has been initialized in cleanup
-		 */
-		kill (child_pid_save, SIGTERM);
 		launcher->priv->busy = FALSE;
 		
-		if (launcher->priv->custom_encoding && launcher->priv->encoding)
-			g_free (launcher->priv->encoding);
 	}
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
 anjuta_launcher_finalize (GObject *obj)
 {
 	AnjutaLauncher *launcher = ANJUTA_LAUNCHER (obj);	
+	if (launcher->priv->custom_encoding && launcher->priv->encoding)
+		g_free (launcher->priv->encoding);
+	
+	g_hash_table_destroy (launcher->priv->env);
+	
 	g_free (launcher->priv);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -413,7 +423,11 @@ anjuta_launcher_send_ptyin (AnjutaLauncher *launcher, const gchar * input_str)
 	gsize bytes_written;
 	GError *err = NULL;
 	
-	if (!input_str || strlen (input_str) == 0) return;
+	g_return_if_fail (launcher);
+	g_return_if_fail (input_str);
+	
+	if (strlen (input_str) == 0) 
+		return;
 
 	do
 	{	
@@ -607,7 +621,6 @@ anjuta_launcher_check_password_real (AnjutaLauncher *launcher,
 					g_free (line);
 					break;
 				case GTK_RESPONSE_CANCEL:
-					anjuta_launcher_send_ptyin (launcher, "<canceled>\n");
 					anjuta_launcher_reset (launcher);
 					break;
 				default:
@@ -752,9 +765,12 @@ anjuta_launcher_scan_output (GIOChannel *channel, GIOCondition condition,
 			g_io_channel_read_chars (channel, buffer, FILE_BUFFER_SIZE-1, &n, &err);
 			if (n > 0) /* There is output */
 			{
-				gchar *utf8_chars;
+				gchar *utf8_chars = NULL;
 				buffer[n] = '\0';
-				utf8_chars = anjuta_util_convert_to_utf8 (buffer);
+				if (!launcher->priv->custom_encoding)
+					utf8_chars = anjuta_util_convert_to_utf8 (buffer);
+				else
+					utf8_chars = g_strdup(buffer);
 				anjuta_launcher_buffered_output (launcher,
 												 ANJUTA_LAUNCHER_OUTPUT_STDOUT,
 												 utf8_chars);
@@ -763,7 +779,6 @@ anjuta_launcher_scan_output (GIOChannel *channel, GIOCondition condition,
 			/* Ignore illegal characters */
 			if (err && err->domain == G_CONVERT_ERROR)
 			{
-				g_warning ("stdout: %s", err->message);
 				g_error_free (err);
 				err = NULL;
 			}
@@ -771,7 +786,6 @@ anjuta_launcher_scan_output (GIOChannel *channel, GIOCondition condition,
 			/* if not related to non blocking read or interrupted syscall */
 			else if (err && errno != EAGAIN && errno != EINTR)
 			{
-				g_warning ("stdout: %s", err->message);
 				launcher->priv->stdout_is_done = TRUE;
 				anjuta_launcher_synchronize (launcher);
 				ret = FALSE;
@@ -819,7 +833,6 @@ anjuta_launcher_scan_error (GIOChannel *channel, GIOCondition condition,
 			/* Ignore illegal characters */
 			if (err && err->domain == G_CONVERT_ERROR)
 			{
-				g_warning ("stderr: %s", err->message);
 				g_error_free (err);
 				err = NULL;
 			}
@@ -827,7 +840,6 @@ anjuta_launcher_scan_error (GIOChannel *channel, GIOCondition condition,
 			/* if not related to non blocking read or interrupted syscall */
 			else if (err && errno != EAGAIN && errno != EINTR)
 			{
-				g_warning ("stderr: %s", err->message);
 				
 				launcher->priv->stderr_is_done = TRUE;
 				anjuta_launcher_synchronize (launcher);
@@ -882,7 +894,6 @@ anjuta_launcher_scan_pty (GIOChannel *channel, GIOCondition condition,
 			/* Ignore illegal characters */
 			if (err && err->domain == G_CONVERT_ERROR)
 			{
-				g_warning ("pty: %s", err->message);
 				g_error_free (err);
 				err = NULL;
 			}
@@ -890,7 +901,6 @@ anjuta_launcher_scan_pty (GIOChannel *channel, GIOCondition condition,
 			/* if not related to non blocking read or interrupted syscall */
 			else if (err && errno != EAGAIN && errno != EINTR)
 			{
-				g_warning ("pty: %s", err->message);
 				ret = FALSE;
 			}
 		/* Read next chars if buffer was too small
@@ -1076,7 +1086,7 @@ anjuta_launcher_set_encoding (AnjutaLauncher *launcher, const gchar *charset)
 	if (launcher->priv->custom_encoding)
 		g_free (launcher->priv->encoding);
 	
-	launcher->priv->custom_encoding = (charset != NULL);
+	launcher->priv->custom_encoding = TRUE;
 	if (charset)
 	  launcher->priv->encoding = g_strdup(charset);
 	else
@@ -1084,13 +1094,14 @@ anjuta_launcher_set_encoding (AnjutaLauncher *launcher, const gchar *charset)
 }
 
 static pid_t
-anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
+anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[], gchar *const envp[])
 {
 	char *working_dir;
 	int pty_master_fd, md;
 	int stdout_pipe[2], stderr_pipe[2];
 	pid_t child_pid;
 	struct termios termios_flags;
+	gchar * const *env;
 	
 	working_dir = g_get_current_dir ();
 	
@@ -1122,6 +1133,28 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 		if ((md = fcntl (stderr_pipe[1], F_GETFL)) != -1)
 			fcntl (stderr_pipe[1], F_SETFL, O_SYNC | md);
 		
+		/* Set up environment */
+		if (envp != NULL)
+		{
+			GString *variable = g_string_new (NULL);
+			for (env = envp; *env != NULL; env++)
+			{
+				gchar *value = strchr (*env, '=');
+
+				if (value == NULL)
+				{
+					g_setenv (*env, NULL, TRUE);
+				}
+				else
+				{
+					g_string_truncate (variable, 0);
+					g_string_append_len (variable, *env, value - *env);
+					g_setenv (variable->str, value + 1, TRUE);
+				}
+			}
+			g_string_free (variable, TRUE);
+		}
+	
 		execvp (args[0], args);
 		g_warning (_("Cannot execute command: \"%s\""), args[0]);
 		perror(_("execvp failed"));
@@ -1171,7 +1204,7 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 	termios_flags.c_iflag |= IGNBRK | BRKINT | IMAXBEL | IXANY;
 	termios_flags.c_oflag &= ~OPOST;
 //	termios_flags.c_oflag |= 0;
-	termios_flags.c_cflag &= ~(CSTOPB | CREAD | PARENB | HUPCL);
+	termios_flags.c_cflag &= ~(CSTOPB | PARENB | HUPCL);
 	termios_flags.c_cflag |= CS8 | CLOCAL;
 
 	if (!launcher->priv->terminal_echo_on)
@@ -1210,6 +1243,7 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
  * anjuta_launcher_execute_v:
  * @launcher: a #AnjutaLancher object.
  * @argv: Command args.
+ * @envp: Additional environment variable.
  * @callback: The callback for delivering output from the process.
  * @callback_data: Callback data for the above callback.
  * 
@@ -1220,6 +1254,7 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
  */
 gboolean
 anjuta_launcher_execute_v (AnjutaLauncher *launcher, gchar *const argv[],
+						   gchar *const envp[],
 						   AnjutaLauncherOutputCallback callback,
 						   gpointer callback_data)
 {
@@ -1238,7 +1273,7 @@ anjuta_launcher_execute_v (AnjutaLauncher *launcher, gchar *const argv[],
 	launcher->priv->callback_data = callback_data;
 	
 	/* On a fork error perform a cleanup and return */
-	if (anjuta_launcher_fork (launcher, argv) < 0)
+	if (anjuta_launcher_fork (launcher, argv, envp) < 0)
 	{
 		anjuta_launcher_initialize (launcher);
 		return FALSE;
@@ -1284,7 +1319,7 @@ anjuta_launcher_execute (AnjutaLauncher *launcher, const gchar *command_str,
 	}
 	*args_ptr = NULL;
 
-	ret = anjuta_launcher_execute_v (launcher, args, 
+	ret = anjuta_launcher_execute_v (launcher, args, NULL,
 		callback, callback_data);
 	g_free (args);
 	anjuta_util_glist_strings_free (args_list);
