@@ -731,7 +731,7 @@ plugin_set_update (AnjutaPluginManager *plugin_manager,
 				if (!anjuta_plugin_deactivate (ANJUTA_PLUGIN (anjuta_plugin)))
 				{
 					anjuta_util_dialog_info (GTK_WINDOW (priv->shell),
-								 "Plugin '%s' do not want to be deactivated",
+								 _("Plugin '%s' do not want to be deactivated"),
 								 anjuta_plugin_handle_get_name (plugin));
 				}
 			}
@@ -1209,7 +1209,7 @@ anjuta_plugin_manager_get_remembered_plugins_page (AnjutaPluginManager *plugin_m
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-	forget_button = gtk_button_new_with_label ("Forget selected plugin");
+	forget_button = gtk_button_new_with_label (_("Forget selected plugin"));
 	gtk_widget_set_sensitive (forget_button, FALSE);
 	gtk_box_pack_end (GTK_BOX (hbox), forget_button, FALSE, FALSE, 0);
 	
@@ -1363,6 +1363,55 @@ get_plugin_factory (AnjutaPluginManager *plugin_manager,
 	return NULL;
 }
 
+static void
+on_is_active_plugins_foreach (gpointer key, gpointer data, gpointer user_data)
+{
+	AnjutaPluginHandle *handle = ANJUTA_PLUGIN_HANDLE (key);
+	gchar const **search_iface = (gchar const **)user_data;
+	
+	if (*search_iface != NULL)
+	{
+		GList *interfaces;
+		GList *found;
+			
+ 		interfaces = anjuta_plugin_handle_get_interfaces (handle);
+		
+		for (found = g_list_first (interfaces); found != NULL; found = g_list_next (found))
+		{
+		}
+		
+		found = g_list_find_custom (interfaces, *search_iface, (GCompareFunc)strcmp);
+		
+		if (found != NULL) *search_iface = NULL;
+	}
+}
+
+/**
+ * anjuta_plugin_manager_is_active_plugin:
+ * @plugin_manager: A #AnjutaPluginManager object
+ * @iface_name: The interface implemented by the object to be found
+ * 
+ * Searches if a currently loaded plugins implements
+ * the given interface.
+ *
+ * Return value: True is the plugin is currently loaded.
+ */
+
+gboolean
+anjuta_plugin_manager_is_active_plugin (AnjutaPluginManager *plugin_manager,
+								  const gchar *iface_name)
+{
+	const gchar *search_iface = iface_name;
+
+	g_return_val_if_fail (ANJUTA_IS_PLUGIN_MANAGER (plugin_manager), FALSE);
+	
+	g_hash_table_foreach (plugin_manager->priv->activated_plugins,
+						  on_is_active_plugins_foreach,
+						  &search_iface);
+	
+	return search_iface == NULL;
+}
+
 /**
  * anjuta_plugin_manager_get_plugin:
  * @plugin_manager: A #AnjutaPluginManager object
@@ -1823,6 +1872,7 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 	gtk_window_set_default_size (GTK_WINDOW (dlg), 400, 300);
 
 	label = gtk_label_new (description);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), label,
 						FALSE, FALSE, 5);
