@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <glib.h>
@@ -93,7 +93,7 @@ void
 on_member_menuitem_clicked (GtkMenuItem *menuitem, gpointer data)
 {
 	NodeData *node;
-	const gchar *file;
+	GFile* file;
 	gint line;
 	
 	node = (NodeData*)data;
@@ -101,7 +101,7 @@ on_member_menuitem_clicked (GtkMenuItem *menuitem, gpointer data)
 	line = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menuitem), "__line"));
 	if (file)
 	{
-		/* Goto file line */
+		/* Goto uri line */
 		IAnjutaDocumentManager *dm;
 		dm = anjuta_shell_get_interface (ANJUTA_PLUGIN (node->plugin)->shell,
 										 IAnjutaDocumentManager, NULL);
@@ -142,15 +142,15 @@ on_nodedata_expanded_event (GnomeCanvasItem *item, GdkEvent *event, gpointer dat
 					g_hash_table_remove (plugin->expansion_node_list, nodedata->name);
 					class_inheritance_update_graph (plugin);
 				}
-			else {		/* it's a class member. Take line && file of definition 
+			else {		/* it's a class member. Take line && uri of definition 
 							 * and reach them */
-				const gchar* file;
+				GFile* file;
 				gint line;
 				
 				file = g_object_get_data (G_OBJECT (item), "__file");
 				line = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "__line"));
 				if (file) {
-					/* Goto file line */
+					/* Goto uri line */
 					IAnjutaDocumentManager *dm;
 					dm = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
 											 	IAnjutaDocumentManager, NULL);
