@@ -19,11 +19,9 @@
 */
 
 #include <config.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-encodings.h>
-#include <libegg/menu/egg-entry-action.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-file-savable.h>
@@ -67,7 +65,14 @@ dispose (GObject *obj)
 {
 	/* EditorPlugin *eplugin = ANJUTA_PLUGIN_EDITOR (obj); */
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
+}
+
+static void
+finalize (GObject *obj)
+{
+	/* Finalization codes here */
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -86,19 +91,23 @@ editor_plugin_class_init (GObjectClass *klass)
 	plugin_class->activate = activate_plugin;
 	plugin_class->deactivate = deactivate_plugin;
 	klass->dispose = dispose;
+	klass->finalize = finalize;
 }
 
 static IAnjutaEditor*
 itext_editor_factory_new_editor(IAnjutaEditorFactory* factory, 
-								const gchar* uri,
+								GFile* file,
 								const gchar* filename, 
 								GError** error)
 {
 	AnjutaShell *shell = ANJUTA_PLUGIN (factory)->shell;
 	AnjutaPreferences *prefs = anjuta_shell_get_preferences (shell, NULL);
 	AnjutaStatus *status = anjuta_shell_get_status (shell, NULL);
+	/* file can be NULL, if we open a buffer, not a file */
+	gchar* uri = file ? g_file_get_uri (file) : NULL;
 	IAnjutaEditor* editor = IANJUTA_EDITOR(text_editor_new(status, prefs,
 														   uri, filename));
+	g_free(uri);
 	return editor;
 }
 
