@@ -60,6 +60,8 @@ gprof_flat_profile_view_create_columns (GProfFlatProfileView *self)
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, renderer, TRUE);
 	gtk_tree_view_column_add_attribute (col, renderer, "text", COL_NAME);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_reorderable (col, TRUE);
 	
 	/* Function time percentage */
 	col = gtk_tree_view_column_new ();
@@ -68,7 +70,12 @@ gprof_flat_profile_view_create_columns (GProfFlatProfileView *self)
 	
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (col, renderer, "text", COL_TIME_PERC);	
+	gtk_tree_view_column_set_cell_data_func (col, renderer, 
+											 gprof_view_format_float,
+											 GINT_TO_POINTER (COL_TIME_PERC),
+											 NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_reorderable (col, TRUE);	
 	
 	/* Cumulative seconds */
 	col = gtk_tree_view_column_new ();
@@ -77,16 +84,29 @@ gprof_flat_profile_view_create_columns (GProfFlatProfileView *self)
 	
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (col, renderer, "text", COL_CUM_SEC);	
+	gtk_tree_view_column_set_cell_data_func (col, renderer, 
+											 gprof_view_format_float,
+											 GINT_TO_POINTER (COL_CUM_SEC),
+											 NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);	
+	gtk_tree_view_column_set_reorderable (col, TRUE);
 	
 	/* Self seconds */
 	col = gtk_tree_view_column_new ();
+	
+	/* The number of seconds that this function, excluding other functions it 
+	 * calls, takes to execute. */
 	gtk_tree_view_column_set_title (col, _("Self Seconds"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), col);
 	
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (col, renderer, "text", COL_SELF_SEC);
+	gtk_tree_view_column_set_cell_data_func (col, renderer, 
+											 gprof_view_format_float,
+											 GINT_TO_POINTER (COL_SELF_SEC),
+											 NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_reorderable (col, TRUE);
 	
 	/* Calls */
 	col = gtk_tree_view_column_new ();
@@ -96,24 +116,41 @@ gprof_flat_profile_view_create_columns (GProfFlatProfileView *self)
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, renderer, TRUE);
 	gtk_tree_view_column_add_attribute (col, renderer, "text", COL_CALLS);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_reorderable (col, TRUE);
 	
 	/* Self ms/call */
 	col = gtk_tree_view_column_new ();
+	
+	/* The average number of milliseconds spent in a function, excluding
+	 * the functions that it calls. */
 	gtk_tree_view_column_set_title (col, _("Self ms/call"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), col);
 	
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (col, renderer, "text", COL_AVG_MS);
+	gtk_tree_view_column_set_cell_data_func (col, renderer, 
+											 gprof_view_format_float,
+											 GINT_TO_POINTER (COL_AVG_MS),
+											 NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_reorderable (col, TRUE);
 	
 	/* Total ms/call */
 	col = gtk_tree_view_column_new ();
+	
+	/* Same as self ms/call, but includes called functions. */
 	gtk_tree_view_column_set_title (col, _("Total ms/call"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), col);
 	
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (col, renderer, TRUE);
-	gtk_tree_view_column_add_attribute (col, renderer, "text", COL_TOTAL_MS);
+	gtk_tree_view_column_set_cell_data_func (col, renderer, 
+											 gprof_view_format_float,
+											 GINT_TO_POINTER (COL_TOTAL_MS),
+											 NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_reorderable (col, TRUE);
 	
 	/* Model setup */
 	gtk_tree_view_set_model (GTK_TREE_VIEW (list_view), 
