@@ -17,8 +17,8 @@
  * You should have received a copy of the GNU General Public License
  * along with plugin.c.  See the file "COPYING".  If not,
  * write to:  The Free Software Foundation, Inc.,
- *            59 Temple Place - Suite 330,
- *            Boston,  MA  02111-1307, USA.
+ *            51 Franklin Street, Fifth Floor,
+ *            Boston,  MA  02110-1301, USA.
  */
 
 #ifndef _GPROF_VIEW_H
@@ -74,6 +74,13 @@ GProfProfileData *gprof_view_get_data (GProfView *self);
 void gprof_view_refresh (GProfView *self);
 GtkWidget *gprof_view_get_widget (GProfView *self);
 
+/* Static methods */
+void gprof_view_format_float (GtkTreeViewColumn *col, 
+							  GtkCellRenderer *renderer,
+							  GtkTreeModel *model,
+							  GtkTreeIter *iter,
+							  gpointer column_number);
+
 G_END_DECLS
 
 #endif
