@@ -26,6 +26,8 @@
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
+#include <libanjuta/interfaces/ianjuta-file-manager.h>
+#include <libanjuta/interfaces/ianjuta-builder.h>
 #include <libanjuta/anjuta-profile-manager.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-status.h>
@@ -41,6 +43,22 @@
 #define DEFAULT_PROFILE "file://"PACKAGE_DATA_DIR"/profiles/default.profile"
 #define PROJECT_PROFILE_NAME "project"
 
+typedef struct _PmPropertiesDialogInfo PmPropertiesDialogInfo;
+
+typedef enum _PmPropertiesType
+{
+	PM_PROJECT_PROPERTIES,
+	PM_TARGET_PROPERTIES,
+	PM_GROUP_PROPERTIES
+} PmPropertiesType;
+
+struct _PmPropertiesDialogInfo
+{
+	PmPropertiesType type;
+	const gchar* id;
+	GtkWidget* dialog;
+};
+
 static gpointer parent_class;
 
 static gboolean uri_is_inside_project (ProjectManagerPlugin *plugin,
@@ -169,8 +187,7 @@ static gboolean
 on_close_project_idle (gpointer plugin)
 {
 	project_manager_plugin_close (ANJUTA_PLUGIN_PROJECT_MANAGER (plugin));
-	/* Self destruct */
-	anjuta_plugin_deactivate (ANJUTA_PLUGIN (plugin));
+	ANJUTA_PLUGIN_PROJECT_MANAGER(plugin)->close_project_idle = -1;
 	
 	return FALSE;
 }
@@ -179,7 +196,7 @@ static void
 on_close_project (GtkAction *action, ProjectManagerPlugin *plugin)
 {
 	if (plugin->project_uri)
-		g_idle_add (on_close_project_idle, plugin);
+		plugin->close_project_idle = g_idle_add (on_close_project_idle, plugin);
 }
 
 static GList *
@@ -323,6 +340,128 @@ update_operation_begin (ProjectManagerPlugin *plugin)
 										  NULL);
 }
 
+/* Properties dialogs functions
+ *---------------------------------------------------------------------------*/
+
+static void
+properties_dialog_info_free (PmPropertiesDialogInfo *info)
+{
+	gtk_widget_destroy (info->dialog);
+	g_free (info);
+}
+
+static gint
+compare_properties_widget (PmPropertiesDialogInfo *info, GtkWidget *widget)
+{
+	return info->dialog == widget ? 0 : 1;
+}
+
+static gint
+compare_properties_id (PmPropertiesDialogInfo *info, PmPropertiesDialogInfo *info1)
+{
+	/* project properties have a NULL id */
+	return (info->type == info1->type) &&
+			((info1->id == NULL) ||
+			 ((info->id != NULL) &&
+			  (strcmp(info->id, info1->id) == 0))) ? 0 : 1;
+}
+
+static void
+on_properties_dialog_response (GtkDialog *win,
+							   gint id,
+							   ProjectManagerPlugin *plugin)
+{
+	GList *prop;
+	
+	prop = g_list_find_custom (plugin->prop_dialogs,
+							   win,
+							   (GCompareFunc)compare_properties_widget);
+	if (prop != NULL)
+	{
+		properties_dialog_info_free ((PmPropertiesDialogInfo *)prop->data);
+		plugin->prop_dialogs = g_list_delete_link (plugin->prop_dialogs, prop);
+	}
+}
+
+/* Display properties dialog. These dialogs are not modal, so keep a list of
+ * them to be able to destroy them if the project is closed. This list is
+ * useful to put the dialog at the top if the same target is selected while
+ * the corresponding dialog already exist instead of creating two times the
+ * same dialog */
+
+static void
+project_manager_show_properties_dialog (ProjectManagerPlugin *plugin,
+										PmPropertiesType type,
+										const gchar *id)
+{
+	PmPropertiesDialogInfo info;
+	GList* prop;
+		
+	info.type = type;
+	info.id = id; 
+	prop = g_list_find_custom (plugin->prop_dialogs,
+							   &info,
+							   (GCompareFunc)compare_properties_id);
+	if (prop != NULL)
+	{
+		/* Show already existing dialog */
+
+		gtk_window_present (GTK_WINDOW (((PmPropertiesDialogInfo *)prop->data)->dialog));
+	}
+	else
+	{
+		/* Create new dialog */
+		GtkWidget *win;
+		GtkWidget *properties = NULL;
+		const char* title = NULL;
+		
+		switch (type)
+		{
+			case PM_PROJECT_PROPERTIES:
+				properties = gbf_project_configure (plugin->project, NULL);
+				title = _("Project properties");
+				break;
+			case PM_TARGET_PROPERTIES:		
+				properties = gbf_project_configure_target (plugin->project,
+														   id, NULL);
+				title = _("Target properties");
+				break;
+			case PM_GROUP_PROPERTIES:
+				properties = gbf_project_configure_group (plugin->project,
+														   id, NULL);
+				title = _("Group properties");
+				break;
+		}
+			
+		if (properties)
+		{
+			win = gtk_dialog_new_with_buttons (title,
+									   GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
+									   GTK_DIALOG_DESTROY_WITH_PARENT,
+									   GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL, NULL);
+			info.dialog = win;
+			plugin->prop_dialogs = g_list_prepend (plugin->prop_dialogs, g_memdup (&info, sizeof (info)));
+			g_signal_connect (win, "response",
+							  G_CALLBACK (on_properties_dialog_response),
+							  plugin);
+			
+			gtk_container_add (GTK_CONTAINER (GTK_DIALOG(win)->vbox),
+							   properties);
+			gtk_window_set_default_size (GTK_WINDOW (win), 450, -1);
+			gtk_widget_show (win);
+		}
+		else
+		{
+			anjuta_util_dialog_info (GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
+							 _("No properties available for this target"));
+		}
+	}	
+}
+
+
+/* GUI callbacks
+ *---------------------------------------------------------------------------*/
+
 static gboolean
 on_refresh_idle (gpointer user_data)
 {
@@ -358,28 +497,7 @@ on_refresh (GtkAction *action, ProjectManagerPlugin *plugin)
 static void
 on_properties (GtkAction *action, ProjectManagerPlugin *plugin)
 {
-	GtkWidget *win, *properties;
-	
-	properties = gbf_project_configure (plugin->project, NULL);
-	if (properties)
-	{
-		win = gtk_dialog_new_with_buttons (_("Project properties"),
-									GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
-									GTK_DIALOG_DESTROY_WITH_PARENT,
-									GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL, NULL);
-		g_signal_connect_swapped (win, "response",
-								  G_CALLBACK (gtk_widget_destroy), win);
-		
-		gtk_container_add (GTK_CONTAINER (GTK_DIALOG(win)->vbox),
-						   properties);
-		gtk_window_set_default_size (GTK_WINDOW (win), 450, -1);
-		gtk_widget_show (win);
-	}
-	else
-	{
-		anjuta_util_dialog_info (GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
-								 _("No properties available for this target"));
-	}
+	project_manager_show_properties_dialog (plugin, PM_PROJECT_PROPERTIES, NULL); 
 }
 
 static void
@@ -442,67 +560,23 @@ static void
 on_popup_properties (GtkAction *action, ProjectManagerPlugin *plugin)
 {
 	GbfTreeData *data;
-	const gchar *selected_target;
-	GtkWidget *properties, *win;
 	
 	data = gbf_project_view_find_selected (GBF_PROJECT_VIEW (plugin->view),
 										   GBF_TREE_NODE_TARGET);
-	selected_target = NULL;
 	if (data)
 	{
-		selected_target = data->id;
-		properties = gbf_project_configure_target (plugin->project,
-												   selected_target, NULL);
-		if (properties)
-		{
-			win = gtk_dialog_new_with_buttons (_("Target properties"),
-								   GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
-								   GTK_DIALOG_DESTROY_WITH_PARENT,
-								   GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL, NULL);
-			g_signal_connect_swapped (win, "response",
-									  G_CALLBACK (gtk_widget_destroy), win);
-			
-			gtk_container_add (GTK_CONTAINER (GTK_DIALOG(win)->vbox),
-							   properties);
-			gtk_window_set_default_size (GTK_WINDOW (win), 450, -1);
-			gtk_widget_show (win);
-		}
-		else
-		{
-			anjuta_util_dialog_info (GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
-								 _("No properties available for this target"));
-		}
+		project_manager_show_properties_dialog (plugin, PM_TARGET_PROPERTIES, data->id);
 		return;
 	}
+		
 	data = gbf_project_view_find_selected (GBF_PROJECT_VIEW (plugin->view),
 										   GBF_TREE_NODE_GROUP);
-	selected_target = NULL;
 	if (data)
 	{
-		selected_target = data->id;
-		properties = gbf_project_configure_group (plugin->project,
-												  selected_target, NULL);
-		if (properties)
-		{
-			win = gtk_dialog_new_with_buttons (_("Group properties"),
-								   GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
-								   GTK_DIALOG_DESTROY_WITH_PARENT,
-								   _("Close"), GTK_RESPONSE_CANCEL, NULL);
-			g_signal_connect_swapped (win, "response",
-									  G_CALLBACK (gtk_widget_destroy), win);
-			
-			gtk_container_add (GTK_CONTAINER (GTK_DIALOG(win)->vbox),
-							   properties);
-			gtk_window_set_default_size (GTK_WINDOW (win), 450, -1);
-			gtk_widget_show (win);
-		}
-		else
-		{
-			anjuta_util_dialog_info (GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell),
-								 _("No properties available for this group"));
-		}
+		project_manager_show_properties_dialog (plugin, PM_GROUP_PROPERTIES, data->id);
 		return;
 	}
+	
 	/* FIXME: */
 }
 
@@ -601,8 +675,7 @@ confirm_removal (ProjectManagerPlugin *plugin, GbfTreeData *data)
 	full_mesg = g_strconcat (question, mesg, NULL);
 	answer =
 		anjuta_util_dialog_boolean_question (get_plugin_parent_window (plugin),
-											 full_mesg, question,
-											 data->name);
+											 full_mesg, data->name);
 	g_free (full_mesg);
 	return answer;
 }
@@ -716,11 +789,13 @@ on_uri_activated (GtkWidget *widget, const gchar *uri,
 				  ProjectManagerPlugin *plugin)
 {
 	IAnjutaFileLoader *loader;
+	GFile* file = g_file_new_for_uri (uri);
 	
 	loader = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
 										 IAnjutaFileLoader, NULL);
 	if (loader)
-		ianjuta_file_loader_load (loader, uri, FALSE, NULL);
+		ianjuta_file_loader_load (loader, file, FALSE, NULL);
+	g_object_unref (file);
 }
 
 static void
@@ -962,14 +1037,14 @@ finally:
 		g_value_init (value, G_TYPE_STRING);
 		g_value_set_string (value, selected_uri);
 		anjuta_shell_add_value (ANJUTA_PLUGIN(plugin)->shell,
-								"project_manager_current_uri",
+								IANJUTA_PROJECT_MANAGER_CURRENT_URI,
 								value, NULL);
 		g_signal_emit_by_name (G_OBJECT (plugin), "element_selected",
 							   selected_uri);
 		g_free (selected_uri);
 	} else {
 		anjuta_shell_remove_value (ANJUTA_PLUGIN(plugin)->shell,
-								   "project_manager_current_uri", NULL);
+								   IANJUTA_PROJECT_MANAGER_CURRENT_URI, NULL);
 	}
 }
 
@@ -1015,15 +1090,16 @@ register_stock_icons (AnjutaPlugin *plugin)
 }
 
 static void
-value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
+value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
 {
 	AnjutaUI *ui;
 	GtkAction *action;
-	const gchar *uri;
+	gchar *uri;
 	ProjectManagerPlugin *pm_plugin;
 	
-	uri = g_value_get_string (value);
+	GFile* file = g_value_get_object (value);
+	uri = g_file_get_uri (file);
 
 	pm_plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (plugin);
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
@@ -1035,10 +1111,11 @@ value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
 	action = anjuta_ui_get_action (ui, "ActionGroupProjectManagerPopup",
 								   "ActionPopupProjectAddToProject");
 	g_object_set (G_OBJECT (action), "sensitive", TRUE, NULL);
+	g_free (uri);
 }
 
 static void
-value_removed_fm_current_uri (AnjutaPlugin *plugin,
+value_removed_fm_current_file (AnjutaPlugin *plugin,
 							  const char *name, gpointer data)
 {
 	AnjutaUI *ui;
@@ -1063,6 +1140,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 {
 	GObject *editor;
 	ProjectManagerPlugin *pm_plugin;
+	GFile* file;
 	
 	editor = g_value_get_object (value);
 	if (!IANJUTA_IS_EDITOR(editor))
@@ -1072,8 +1150,15 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	
 	if (pm_plugin->current_editor_uri)
 		g_free (pm_plugin->current_editor_uri);
-	pm_plugin->current_editor_uri =
-		ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
+	file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+	if (file)
+	{
+		pm_plugin->current_editor_uri = g_file_get_uri (file);
+		g_object_unref (file);
+	}
+	else
+		pm_plugin->current_editor_uri = NULL;
+
 }
 
 static void
@@ -1227,8 +1312,10 @@ project_manager_unload_gbf (ProjectManagerPlugin *pm_plugin)
 					node = g_list_next(node);
 					continue;
 				}
-				gchar *editor_uri =
-					ianjuta_file_get_uri (IANJUTA_FILE (node->data), NULL);
+				GFile* editor_file = ianjuta_file_get_file (IANJUTA_FILE (node->data), NULL);
+				gchar *editor_uri = g_file_get_uri (editor_file);
+				g_object_unref (editor_file);
+					
 				
 				/* Only remove if it does not have unsaved data */
 				if (editor_uri && (!IANJUTA_IS_FILE_SAVABLE (node->data) ||
@@ -1261,6 +1348,11 @@ project_manager_unload_gbf (ProjectManagerPlugin *pm_plugin)
 				g_list_free (to_remove);
 		}
 		
+		/* Remove remaining properties dialogs */
+		g_list_foreach (pm_plugin->prop_dialogs, (GFunc)properties_dialog_info_free, NULL);
+		g_list_free (pm_plugin->prop_dialogs);
+		pm_plugin->prop_dialogs = NULL;
+		
 		/* Release project */
 		g_object_unref (pm_plugin->project);
 		pm_plugin->project = NULL;
@@ -1294,7 +1386,7 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 	
 	update_title (plugin, plugin->project_root_uri);
 	anjuta_shell_add_value (ANJUTA_PLUGIN(plugin)->shell,
-							"project_root_uri",
+							IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 							value, NULL);
 	
 	/* If profile scoped to "project", restore project session */
@@ -1340,7 +1432,7 @@ on_profile_descoped (AnjutaProfileManager *profile_manager,
 	
 	update_title (ANJUTA_PLUGIN_PROJECT_MANAGER (plugin), NULL);
 	anjuta_shell_remove_value (ANJUTA_PLUGIN (plugin)->shell,
-							   "project_root_uri", NULL);
+						  IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI, NULL);
 }
 
 static void
@@ -1414,6 +1506,7 @@ project_manager_plugin_activate_plugin (AnjutaPlugin *plugin)
 	pm_plugin->scrolledwindow = scrolled_window;
 	pm_plugin->view = view;
 	pm_plugin->model = model;
+	pm_plugin->prop_dialogs = NULL;
 	
 	/* Action groups */
 	pm_plugin->pm_action_group = 
@@ -1455,11 +1548,11 @@ project_manager_plugin_activate_plugin (AnjutaPlugin *plugin)
 	
 	/* Add watches */
 	pm_plugin->fm_watch_id =
-		anjuta_plugin_add_watch (plugin, "file_manager_current_uri",
-								 value_added_fm_current_uri,
-								 value_removed_fm_current_uri, NULL);
+		anjuta_plugin_add_watch (plugin, IANJUTA_FILE_MANAGER_SELECTED_FILE,
+								 value_added_fm_current_file,
+								 value_removed_fm_current_file, NULL);
 	pm_plugin->editor_watch_id = 
-		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
+		anjuta_plugin_add_watch (plugin, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
 	/* Connect to save session */
@@ -1483,7 +1576,12 @@ project_manager_plugin_deactivate_plugin (AnjutaPlugin *plugin)
 	AnjutaProfileManager *profile_manager;
 	ProjectManagerPlugin *pm_plugin;
 	pm_plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (plugin);
-	
+
+	if (pm_plugin->close_project_idle > -1)
+	{
+		g_source_remove (pm_plugin->close_project_idle);
+	}
+
 	/* Close project if it's open */
 	if (pm_plugin->project_root_uri)
 		project_manager_plugin_close (pm_plugin);
@@ -1524,14 +1622,14 @@ static void
 project_manager_plugin_finalize (GObject *obj)
 {
 	/* FIXME: */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
 project_manager_plugin_dispose (GObject *obj)
 {
 	/* FIXME: */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
@@ -1550,6 +1648,7 @@ project_manager_plugin_instance_init (GObject *obj)
 	plugin->fm_current_uri = NULL;
 	plugin->current_editor_uri = NULL;
 	plugin->session_by_me = FALSE;
+	plugin->close_project_idle = -1;
 }
 
 static void
@@ -1596,7 +1695,7 @@ uri_is_inside_project (ProjectManagerPlugin *plugin, const gchar *uri)
 }
 
 static gchar *
-get_element_uri_from_id (ProjectManagerPlugin *plugin, const gchar *id)
+get_element_uri_from_id (ProjectManagerPlugin *plugin, const gchar *id, const gchar *root)
 {
 	gchar *path, *ptr;
 	gchar *uri;
@@ -1609,17 +1708,18 @@ get_element_uri_from_id (ProjectManagerPlugin *plugin, const gchar *id)
 	ptr = strrchr (path, ':');
 	if (ptr)
 	{
+		*ptr = '\0';
 		if (ptr[1] == '/')
 		{
 			 /* ID is source ID, extract source uri */
-			ptr = strrchr (ptr, ':');
-			return g_strdup (ptr+1);
+			uri = strrchr (path, ':');		/* keep uri scheme */
+			*ptr = ':';
+			return g_strdup (uri+1);
 		}
-		*ptr = '\0';
 	}
 	
 	anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell,
-					  "project_root_uri", G_TYPE_STRING,
+					  root, G_TYPE_STRING,
 					  &project_root, NULL);
 	uri = g_build_filename (project_root, path, NULL);
 	/* DEBUG_PRINT ("Converting id: %s to %s", id, uri); */
@@ -1628,12 +1728,12 @@ get_element_uri_from_id (ProjectManagerPlugin *plugin, const gchar *id)
 }
 
 static const gchar *
-get_element_relative_path (ProjectManagerPlugin *plugin, const gchar *uri)
+get_element_relative_path (ProjectManagerPlugin *plugin, const gchar *uri, const gchar *root)
 {
 	const gchar *project_root = NULL;
 	
 	anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell,
-					  "project_root_uri", G_TYPE_STRING,
+					  root, G_TYPE_STRING,
 					  &project_root, NULL);
 	if (project_root)
 	{
@@ -1661,7 +1761,7 @@ get_target_from_uri (ProjectManagerPlugin *plugin, const gchar *uri)
 	const gchar *rel_path;
 	gchar *test_id;
 	
-	rel_path = get_element_relative_path (plugin, uri);
+	rel_path = get_element_relative_path (plugin, uri, IANJUTA_BUILDER_ROOT_URI);
 	
 	if (!rel_path)
 		return NULL;
@@ -1709,11 +1809,11 @@ get_element_id_from_uri (ProjectManagerPlugin *plugin, const gchar *uri)
 	}
 	else if (get_uri_vfs_type (uri) | GNOME_VFS_FILE_TYPE_DIRECTORY)
 	{
-		id = g_strconcat (get_element_relative_path (plugin, uri), "/", NULL);
+		id = g_strconcat (get_element_relative_path (plugin, uri, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI), "/", NULL);
 	}
 	else
 	{
-		id = strdup (get_element_relative_path (plugin, uri));
+		id = strdup (get_element_relative_path (plugin, uri, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI));
 	}
 	return id;
 }
@@ -1799,7 +1899,8 @@ iproject_manager_get_elements (IAnjutaProjectManager *project_manager,
 			{
 				elements = g_list_prepend (elements,
 										   get_element_uri_from_id (plugin,
-												(const gchar *)node->data));
+												(const gchar *)node->data,
+												IANJUTA_BUILDER_ROOT_URI));
 				g_free (node->data);
 				node = node->next;
 			}
@@ -1815,7 +1916,8 @@ iproject_manager_get_elements (IAnjutaProjectManager *project_manager,
 			{
 				elements = g_list_prepend (elements,
 										   get_element_uri_from_id (plugin,
-												(const gchar *)node->data));
+												(const gchar *)node->data,
+										        IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI));
 				g_free (node->data);
 				node = node->next;
 			}
@@ -1928,7 +2030,8 @@ iproject_manager_get_targets (IAnjutaProjectManager *project_manager,
 				if (strcmp (t_type, type_node->data) == 0)
 				{
 					gchar *target_uri = get_element_uri_from_id (plugin,
-																 target_id);
+																 target_id,
+																 IANJUTA_BUILDER_ROOT_URI);
 					elements = g_list_prepend (elements, target_uri);
 				}
 			}
@@ -1985,6 +2088,8 @@ iproject_manager_get_selected (IAnjutaProjectManager *project_manager,
 	g_return_val_if_fail (ANJUTA_IS_PLUGIN (project_manager), NULL);
 	
 	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (G_OBJECT (project_manager));
+	if (plugin->project == NULL) return NULL;
+	
 	g_return_val_if_fail (GBF_IS_PROJECT (plugin->project), NULL);
 	
 	data = gbf_project_view_find_selected (GBF_PROJECT_VIEW (plugin->view),
@@ -2003,7 +2108,7 @@ iproject_manager_get_selected (IAnjutaProjectManager *project_manager,
 										   GBF_TREE_NODE_TARGET);
 	if (data && data->type == GBF_TREE_NODE_TARGET)
 	{
-		uri = get_element_uri_from_id (plugin, data->id);
+		uri = get_element_uri_from_id (plugin, data->id, IANJUTA_BUILDER_ROOT_URI);
 		gbf_tree_data_free (data);
 		return uri;
 	}
@@ -2057,10 +2162,17 @@ iproject_manager_add_source (IAnjutaProjectManager *project_manager,
 	g_return_val_if_fail (GBF_IS_PROJECT (plugin->project), FALSE);
 
 	update_operation_begin (plugin);
-	default_location_type =
-		ianjuta_project_manager_get_element_type (project_manager,
-												  default_location_uri, NULL);
-	location_id = get_element_id_from_uri (plugin, default_location_uri);
+	if (default_location_uri == NULL)
+	{
+		default_location_type = IANJUTA_PROJECT_MANAGER_UNKNOWN;
+	}
+	else
+	{
+		default_location_type =
+			ianjuta_project_manager_get_element_type (project_manager,
+													  default_location_uri, NULL);
+		location_id = get_element_id_from_uri (plugin, default_location_uri);
+	}
 	if (default_location_type == IANJUTA_PROJECT_MANAGER_GROUP)
 	{
 		source_id = gbf_project_util_add_source (plugin->model,
@@ -2084,7 +2196,7 @@ iproject_manager_add_source (IAnjutaProjectManager *project_manager,
 	}
 	update_operation_end (plugin, TRUE);
 	
-	source_uri = get_element_uri_from_id(plugin, source_id);
+	source_uri = get_element_uri_from_id(plugin, source_id, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI);
 	g_free(source_id);
 	
 	return source_uri;
@@ -2141,7 +2253,8 @@ iproject_manager_add_source_multi (IAnjutaProjectManager *project_manager,
 	{
 		source_uris = g_list_append (source_uris,
 									 get_element_uri_from_id (plugin,
-														  source_ids->data));
+														  source_ids->data,
+														  IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI));
 		g_free (source_ids->data);
 		source_ids = g_list_next(source_ids);
 	}
@@ -2172,7 +2285,7 @@ iproject_manager_add_target (IAnjutaProjectManager *project_manager,
 											 default_group_id,
 											 target_name_to_add);
 	update_operation_end (plugin, TRUE);
-	target_uri = get_element_uri_from_id (plugin, target_id);
+	target_uri = get_element_uri_from_id (plugin, target_id, IANJUTA_BUILDER_ROOT_URI);
 	g_free (target_id);
 	g_free (default_group_id);
 	return target_uri;
@@ -2201,7 +2314,7 @@ iproject_manager_add_group (IAnjutaProjectManager *project_manager,
 										   default_group_id,
 										   group_name_to_add);
 	update_operation_end (plugin, TRUE);
-	group_uri = get_element_uri_from_id (plugin, group_id);
+	group_uri = get_element_uri_from_id (plugin, group_id, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI);
 	g_free (group_id);
 	g_free (default_group_id);
 	return group_uri;
@@ -2217,6 +2330,28 @@ iproject_manager_is_open (IAnjutaProjectManager *project_manager, GError **err)
 	return GBF_IS_PROJECT (plugin->project);
 }
 
+static GList*
+iproject_manager_get_packages (IAnjutaProjectManager *project_manager, GError **err)
+{
+	ProjectManagerPlugin *plugin;
+	GList *modules = NULL;
+	GList *packages = NULL;
+	GList* node;
+	
+	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (G_OBJECT (project_manager));
+	
+	modules = gbf_project_get_config_modules (plugin->project, NULL);
+	for (node = modules; node != NULL; node = g_list_next (node))
+	{
+		GList* mod_pkgs = gbf_project_get_config_packages (plugin->project,
+														   node->data, NULL);
+		packages = g_list_concat (packages, mod_pkgs);
+	}
+	g_list_foreach (modules, (GFunc)g_free, NULL);
+	g_list_free (modules);
+	return packages;
+}
+
 static void
 iproject_manager_iface_init(IAnjutaProjectManagerIface *iface)
 {
@@ -2233,24 +2368,25 @@ iproject_manager_iface_init(IAnjutaProjectManagerIface *iface)
 	iface->add_target = iproject_manager_add_target;
 	iface->add_group = iproject_manager_add_group;
 	iface->is_open = iproject_manager_is_open;
+	iface->get_packages = iproject_manager_get_packages;
 }
 
 static void
-ifile_open (IAnjutaFile *ifile, const gchar* uri, GError **e)
+ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 {
 	AnjutaProfile *profile;
 	AnjutaProfileManager *profile_manager;
 	AnjutaPluginManager *plugin_manager;
 	AnjutaStatus *status;
-	GnomeVFSURI *vfs_uri;
 	gchar *dirname, *dirname_tmp, *vfs_dir;
 	gchar *session_profile, *profile_name;
 	ProjectManagerPlugin *plugin;
 	GError *error = NULL;
+	gchar* uri = g_file_get_uri (file);
+	GnomeVFSURI* vfs_uri;
 	
 	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (ifile);
 	
-#if 1 /* Enable it now */
 	/* If there is already a project loaded, load in separate anjuta window */
 	if (plugin->project_root_uri)
 	{
@@ -2261,7 +2397,6 @@ ifile_open (IAnjutaFile *ifile, const gchar* uri, GError **e)
 		g_free (cmd);
 		return;
 	}
-#endif
 	
 	plugin_manager  =
 		anjuta_shell_get_plugin_manager (ANJUTA_PLUGIN (ifile)->shell, NULL);
@@ -2270,10 +2405,6 @@ ifile_open (IAnjutaFile *ifile, const gchar* uri, GError **e)
 	status = anjuta_shell_get_status (ANJUTA_PLUGIN (ifile)->shell, NULL);
 	
 	anjuta_status_progress_add_ticks (status, 2);
-#if 0	
-	/* Freeze shell */
-	anjuta_shell_freeze (ANJUTA_PLUGIN (ifile)->shell, NULL);
-#endif
 	/* Prepare profile */
 	profile = anjuta_profile_new (PROJECT_PROFILE_NAME, plugin_manager);
 	
@@ -2350,26 +2481,19 @@ ifile_open (IAnjutaFile *ifile, const gchar* uri, GError **e)
 	anjuta_status_progress_tick (status, NULL,
 								 _("Loaded Project... Initializing"));
 	update_ui (plugin);
-#if 0
-	/* Thaw shell */
-	/* FIXME: The shell can not be thawed after the session is loaded,
-	 * because the layout is loaded in the session. If shell is not thawed
-	 * before that, the widgets on which layout is applied are not present
-	 * side the shell (freezing delays the widgets addition).
-	 */
-	anjuta_shell_thaw (ANJUTA_PLUGIN (ifile)->shell, NULL);
-#endif
+
 	anjuta_status_progress_tick (status, NULL, _("Loaded Project..."));
+	g_free (uri);
 }
 
-static gchar*
-ifile_get_uri (IAnjutaFile *ifile, GError **e)
+static GFile*
+ifile_get_file (IAnjutaFile *ifile, GError **e)
 {
 	ProjectManagerPlugin *plugin;
 	
 	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (ifile);
 	if (plugin->project_root_uri)
-		return g_strdup (plugin->project_root_uri);
+		return g_file_new_for_uri (plugin->project_root_uri);
 	else
 		return NULL;
 }
@@ -2378,7 +2502,7 @@ static void
 ifile_iface_init(IAnjutaFileIface *iface)
 {
 	iface->open = ifile_open;
-	iface->get_uri = ifile_get_uri;
+	iface->get_file = ifile_get_file;
 }
 
 ANJUTA_PLUGIN_BEGIN (ProjectManagerPlugin, project_manager_plugin);
