@@ -27,7 +27,7 @@
  * list of people on the anjuta Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: anjuta-view.c 3918 2008-05-06 11:15:58Z jhs $ 
+ * $Id: anjuta-view.c 4055 2008-07-05 15:08:05Z jhs $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -102,15 +102,6 @@ scroll_to_cursor_real (AnjutaView *view)
 	return FALSE;
 }
 
-static void
-document_read_only_notify_handler (AnjutaDocument *document, 
-			           GParamSpec    *pspec,
-				   AnjutaView     *view)
-{
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), 
-				    !anjuta_document_get_readonly (document));
-}
-
 static void
 anjuta_view_set_property (GObject * object,
 			   guint property_id,
@@ -383,20 +374,10 @@ anjuta_view_new (Sourceview *sv)
 {
 	GtkWidget *view;
 
-	g_return_val_if_fail (ANJUTA_IS_DOCUMENT (sv->priv->document), NULL);
-
 	view = GTK_WIDGET (g_object_new (ANJUTA_TYPE_VIEW, NULL));
 	
 	gtk_text_view_set_buffer (GTK_TEXT_VIEW (view),
 				  GTK_TEXT_BUFFER (sv->priv->document));
-  		
-	g_signal_connect (sv->priv->document,
-			  "notify::read-only",
-			  G_CALLBACK (document_read_only_notify_handler),
-			  view);
-
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), 
-				    !anjuta_document_get_readonly (sv->priv->document));					  
 
 	gtk_widget_show_all (view);
 
@@ -416,14 +397,16 @@ anjuta_view_cut_clipboard (AnjutaView *view)
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	g_return_if_fail (buffer != NULL);
 
+	if (!gtk_text_view_get_editable (GTK_TEXT_VIEW(view)))
+		return;
+	
 	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (view),
 					      GDK_SELECTION_CLIPBOARD);
 
 	/* FIXME: what is default editability of a buffer? */
   	gtk_text_buffer_cut_clipboard (buffer,
   				       clipboard,
-				       !anjuta_document_get_readonly (
-				       		ANJUTA_DOCUMENT (buffer)));
+				       TRUE);
   	
 	gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
 				      gtk_text_buffer_get_insert (buffer),
@@ -470,8 +453,7 @@ anjuta_view_paste_clipboard (AnjutaView *view)
   	gtk_text_buffer_paste_clipboard (buffer,
 					 clipboard,
 					 NULL,
-					 !anjuta_document_get_readonly (
-						ANJUTA_DOCUMENT (buffer)));
+					 TRUE);
 
 	gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
 				      gtk_text_buffer_get_insert (buffer),
@@ -494,8 +476,7 @@ anjuta_view_delete_selection (AnjutaView *view)
 	/* FIXME: what is default editability of a buffer? */
 	gtk_text_buffer_delete_selection (buffer,
 					  TRUE,
-					  !anjuta_document_get_readonly (
-						ANJUTA_DOCUMENT (buffer)));
+					  TRUE);
 						
 	gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (view),
 				      gtk_text_buffer_get_insert (buffer),
@@ -569,11 +550,11 @@ anjuta_view_expose (GtkWidget      *widget,
                    GdkEventExpose *event)
 {
 	GtkTextView *text_view;
-	AnjutaDocument *doc;
+	GtkTextBuffer *doc;
 	
 	text_view = GTK_TEXT_VIEW (widget);
 	
-	doc = ANJUTA_DOCUMENT (gtk_text_view_get_buffer (text_view));
+	doc = gtk_text_view_get_buffer (text_view);
 	
 	if ((event->window == gtk_text_view_get_window (text_view, GTK_TEXT_WINDOW_TEXT)))
 	{
