@@ -38,13 +38,12 @@ static AnjutaPreferences* prefs = NULL;
 #define VIEW_LINENUMBERS           "margin.linenumber.visible"
 #define VIEW_MARKS                 "margin.marker.visible"
 #define VIEW_RIGHTMARGIN           "sourceview.rightmargin.visible"
+#define VIEW_WHITE_SPACES          "view.whitespace"
+#define VIEW_EOL                   "view.eol"
+#define VIEW_LINE_WRAP             "view.line.wrap"
 #define RIGHTMARGIN_POSITION       "sourceview.rightmargin.position"
 
-#define COLOR_THEME "sourceview.color.use_theme"
-#define COLOR_TEXT	"sourceview.color.text"
-#define COLOR_BACKGROUND	"sourceview.color.background"
-#define COLOR_SELECTED_TEXT	"sourceview.color.selected_text"
-#define COLOR_SELECTION	"sourceview.color.selection"
+
 
 #define FONT_THEME "sourceview.font.use_theme"
 #define FONT "sourceview.font"
@@ -69,6 +68,56 @@ get_bool(GConfEntry* entry)
 		return gconf_value_get_int(value);
 }
 
+static void
+on_gconf_notify_view_spaces (GConfClient *gclient, guint cnxn_id,
+														 GConfEntry *entry, gpointer user_data)
+{
+	Sourceview *sv;
+	gboolean visible = get_bool(entry);
+	sv = ANJUTA_SOURCEVIEW(user_data);
+	GtkSourceDrawSpacesFlags flags = 
+		gtk_source_view_get_draw_spaces (GTK_SOURCE_VIEW (sv->priv->view));
+	
+	if (visible)
+		flags |= (GTK_SOURCE_DRAW_SPACES_SPACE | GTK_SOURCE_DRAW_SPACES_TAB);
+	else
+		flags &= ~(GTK_SOURCE_DRAW_SPACES_SPACE | GTK_SOURCE_DRAW_SPACES_TAB);
+		
+	gtk_source_view_set_draw_spaces (GTK_SOURCE_VIEW(sv->priv->view), 
+																	 flags);
+}
+
+static void
+on_gconf_notify_view_eols (GConfClient *gclient, guint cnxn_id,
+													 GConfEntry *entry, gpointer user_data)
+{
+	Sourceview *sv;
+	gboolean visible = get_bool(entry);
+	sv = ANJUTA_SOURCEVIEW(user_data);
+	GtkSourceDrawSpacesFlags flags = 
+		gtk_source_view_get_draw_spaces (GTK_SOURCE_VIEW (sv->priv->view));
+	
+	if (visible)
+		flags |= GTK_SOURCE_DRAW_SPACES_NEWLINE;
+	else
+		flags &= ~GTK_SOURCE_DRAW_SPACES_NEWLINE;
+		
+	gtk_source_view_set_draw_spaces (GTK_SOURCE_VIEW(sv->priv->view), 
+																	 flags);
+}
+
+static void
+on_gconf_notify_line_wrap (GConfClient *gclient, guint cnxn_id,
+													 GConfEntry *entry, gpointer user_data)
+{
+	Sourceview *sv;
+	gboolean line_wrap = get_bool(entry);
+	sv = ANJUTA_SOURCEVIEW(user_data);
+	
+	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (sv->priv->view),
+															 line_wrap ? GTK_WRAP_WORD : GTK_WRAP_NONE);
+}
+
 static void
 on_gconf_notify_disable_hilite (GConfClient *gclient, guint cnxn_id,
 																GConfEntry *entry, gpointer user_data)
@@ -198,41 +247,6 @@ on_gconf_notify_right_margin_position (GConfClient *gclient, guint cnxn_id,
 	
 }
 
-static void
-on_gconf_notify_color (GConfClient *gclient, guint cnxn_id,
-											 GConfEntry *entry, gpointer user_data)
-{
-	Sourceview *sv;
-	GdkColor *text, *background, *selected_text, *selection;
-	AnjutaPreferences* prefs = sourceview_get_prefs();
-	sv = ANJUTA_SOURCEVIEW(user_data);
-	
-  if (!anjuta_preferences_get_int (prefs, COLOR_THEME))
-  {
-    text = anjuta_util_convert_color(prefs, COLOR_TEXT);
-    background = anjuta_util_convert_color(prefs, COLOR_BACKGROUND);
-    selected_text = anjuta_util_convert_color(prefs, COLOR_SELECTED_TEXT);
-    selection = anjuta_util_convert_color(prefs, COLOR_SELECTION);
-    anjuta_view_set_colors(sv->priv->view, FALSE, background, text, selection, selected_text);
-  }
-}
-
-static void
-on_gconf_notify_color_theme (GConfClient *gclient, guint cnxn_id,
-														 GConfEntry *entry, gpointer user_data)
-{
-	Sourceview *sv;
-	gboolean use_theme = get_bool(entry);
-	sv = ANJUTA_SOURCEVIEW(user_data);
-	
-	if (use_theme)
-	{
-		anjuta_view_set_colors(sv->priv->view, TRUE, NULL, NULL, NULL, NULL);
-	}
-	else
-		on_gconf_notify_color(NULL, 0, NULL, sv);
-}
-
 static void
 on_gconf_notify_font (GConfClient *gclient, guint cnxn_id,
 											GConfEntry *entry, gpointer user_data)
@@ -272,13 +286,11 @@ on_gconf_notify_font_theme (GConfClient *gclient, guint cnxn_id,
 }
 
 static void
-init_colors_and_fonts(Sourceview* sv)
+init_fonts(Sourceview* sv)
 {
 	gboolean font_theme;
-	gboolean color_theme;
 	
 	font_theme = anjuta_preferences_get_int(prefs, FONT_THEME);
-	color_theme = anjuta_preferences_get_int(prefs, COLOR_THEME);
 	
 	if (!font_theme)
 	{
@@ -299,10 +311,6 @@ init_colors_and_fonts(Sourceview* sv)
 		g_free (desktop_fixed_font);
 		g_object_unref (gclient);
 	}
- 	if (!color_theme)
-  		on_gconf_notify_color (NULL, 0, NULL, sv);
-	else
-		anjuta_view_set_colors(sv->priv->view, TRUE, NULL, NULL, NULL, NULL);
 }
 
 static int
@@ -315,6 +323,7 @@ void
 sourceview_prefs_init(Sourceview* sv)
 {
 	guint notify_id;
+	GtkSourceDrawSpacesFlags flags = 0;
 	
 	prefs = sv->priv->prefs;
 	
@@ -336,9 +345,19 @@ sourceview_prefs_init(Sourceview* sv)
 																				get_key(sv, VIEW_RIGHTMARGIN));
 	gtk_source_view_set_right_margin_position(GTK_SOURCE_VIEW(sv->priv->view), 
 																						get_key(sv, RIGHTMARGIN_POSITION));
+	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (sv->priv->view),
+															 get_key (sv, VIEW_EOL) ? GTK_WRAP_WORD : GTK_WRAP_NONE);
+
 	
+	if (get_key (sv, VIEW_WHITE_SPACES))
+		flags |= (GTK_SOURCE_DRAW_SPACES_SPACE | GTK_SOURCE_DRAW_SPACES_TAB);
+	if (get_key (sv, VIEW_EOL))
+		flags |= GTK_SOURCE_DRAW_SPACES_NEWLINE;
 	
-	init_colors_and_fonts(sv);
+	gtk_source_view_set_draw_spaces (GTK_SOURCE_VIEW (sv->priv->view),
+																	 flags);
+	
+	init_fonts(sv);
 	
 	/* Register gconf notifications */
 	REGISTER_NOTIFY (TAB_SIZE, on_gconf_notify_tab_size);
@@ -350,15 +369,12 @@ sourceview_prefs_init(Sourceview* sv)
 	REGISTER_NOTIFY (VIEW_MARKS, on_gconf_notify_view_marks);
 	REGISTER_NOTIFY (VIEW_LINENUMBERS, on_gconf_notify_view_linenums);
 	REGISTER_NOTIFY (VIEW_RIGHTMARGIN, on_gconf_notify_view_right_margin);
+	REGISTER_NOTIFY (VIEW_WHITE_SPACES, on_gconf_notify_view_spaces);		
+	REGISTER_NOTIFY (VIEW_EOL, on_gconf_notify_view_eols);		  
+	REGISTER_NOTIFY (VIEW_LINE_WRAP, on_gconf_notify_line_wrap);		  
 	REGISTER_NOTIFY (RIGHTMARGIN_POSITION, on_gconf_notify_right_margin_position);
-	REGISTER_NOTIFY (COLOR_THEME, on_gconf_notify_color_theme);
-	REGISTER_NOTIFY (COLOR_TEXT, on_gconf_notify_color);
-	REGISTER_NOTIFY (COLOR_BACKGROUND, on_gconf_notify_color);
-	REGISTER_NOTIFY (COLOR_SELECTED_TEXT, on_gconf_notify_color);
-	REGISTER_NOTIFY (COLOR_SELECTION, on_gconf_notify_color);
 	REGISTER_NOTIFY (FONT_THEME, on_gconf_notify_font_theme);
 	REGISTER_NOTIFY (FONT, on_gconf_notify_font);	
-	
 }
 
 void sourceview_prefs_destroy(Sourceview* sv)
