@@ -29,7 +29,7 @@
 #include <limits.h>
 
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "vgcachegrindprefs.h"
 
